# Contributing

If you would like to contribute to Pydatpiff please visit the project's
[**Pydatpiff Page**][pydatpiff_repo]

## How To Contribute

To contribute to this repo, open a pull request with
your changes.

To have the best experience while contributing, Contributers are urge to follow the guideline below:

* Have fun !! :smile:
* Fork this [**repo**][pydatpiff_repo]
* Create a branch for your new feature/bug fix
* Write tests for your new feature/bug fix and submit them in the root `tests` folder
* Ensure that existing tests pass before submitting your Pull Request
* Update the readme/docstrings, if necessary
* Follow the coding style of the current code-base
* Ensure that your code is PEP8 compliant and is neatly written
* Ensure that your changes work with the following Python versions: python >=3.5



All codes are reviewed before acceptance and changes may be requested to better
follow the conventions of the existing Repo.

This build system currently uses **`tox`** for testing on all supported Python versions.

All tests will run automatically for all **`push`** and **`PR`** via GitHub Actions.
You should ensure your build will pass by running `tox` tests locally before submitting PR.

---

## Thank You For Contributing
[pydatpiff_repo]:https://github.com/cbedroid/pydatpiff
